Presence Role - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Presence Role

Presence roles are what indicate how a person was involved with an event, such as a subject, a witness, or a regular attendee. They inherit from `betty.model.ancestry.PresenceRole`.

## Presence roles

`betty.model.ancestry.Subject`

  The person was a primary subject at the event, such as the person being born at a birth, or one of the happy couple at a wedding.

`betty.model.ancestry.Witness`

  The person was a witness at an event where other people were the subjects.

`betty.model.ancestry.Beneficiary`

  The person was the event’s beneficiary, such as when a will was read.

`betty.model.ancestry.Attendee`

  The person was an attendee at the event and no additional details about their involvement are known.

`betty.model.ancestry.Speaker`

  The person performed public speaking at the event.

`betty.model.ancestry.Celebrant`

  The person was the celebrant or officiant at the event, such as a civil servant or a clergyperson.

`betty.model.ancestry.Organizer`

  The person organized the event.